# -*- rpm-spec -*-

Summary: A CIM provider for libvirt
Name: libvirt-cim
Version: 0.5.8
Release: 3%{?dist}
License: LGPLv2+
Group: Development/Libraries
Source: libvirt-cim-%{version}.tar.gz
Patch0: libvirt-cim-0.5.8-xen-net-source.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
URL: http://libvirt.org/CIM/
Requires: unzip
Requires: libvirt >= 0.6.3
Requires: libxml2 >= 2.6.0
Requires: tog-pegasus
BuildRequires: libcmpiutil >= 0.4
BuildRequires: tog-pegasus-devel
BuildRequires: libvirt-devel >= 0.6.3
BuildRequires: e2fsprogs-devel
BuildRequires: libxml2-devel
BuildRequires: libcmpiutil-devel
BuildConflicts: sblim-cmpi-devel
# limited to the set of arches where libvirt is present
ExclusiveArch: i386 x86_64 ia64

%description
Libvirt-cim is a CMPI CIM provider that implements the DMTF SVPC
virtualization model. The goal is to support most of the features
exported by libvirt itself, enabling management of multiple
platforms with a single provider.

%prep
%setup -q
%patch0 -p1

chmod -f -x src/* libxkutil/* schema/* README doc/* #base_schema/README*
chmod +X src/* libxkutil/* schema/*

%build
%configure --disable-werror
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
make %{?_smp_mflags}

%install
rm -fr $RPM_BUILD_ROOT

make DESTDIR=$RPM_BUILD_ROOT install
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/cmpi/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/cmpi/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libxkutil.so
mkdir -p $RPM_BUILD_ROOT/etc/ld.so.conf.d
echo %{_libdir}/cmpi > $RPM_BUILD_ROOT/etc/ld.so.conf.d/libvirt-cim.conf
mkdir -p $RPM_BUILD_ROOT/etc/libvirt/cim

%clean
rm -fr $RPM_BUILD_ROOT

%pre
%define REGISTRATION %{_datadir}/%{name}/*.registration
%define SCHEMA %{_datadir}/%{name}/*.mof

%define INTEROP_REG %{_datadir}/%{name}/{RegisteredProfile,ElementConformsToProfile,ReferencedProfile}.registration
%define INTEROP_MOF %{_datadir}/%{name}/{ComputerSystem,HostSystem,RegisteredProfile,DiskPool,MemoryPool,NetPool,ProcessorPool,VSMigrationService,ElementConformsToProfile,ReferencedProfile,AllocationCapabilities}.mof

%define PGINTEROP_REG %{_datadir}/%{name}/{RegisteredProfile,ElementConformsToProfile,ReferencedProfile}.registration
%define PGINTEROP_MOF %{_datadir}/%{name}/{RegisteredProfile,ElementConformsToProfile,ReferencedProfile}.mof

%define CIMV2_REG %{_datadir}/%{name}/{HostedResourcePool,ElementCapabilities,HostedService,HostedDependency,ElementConformsToProfile,HostedAccessPoint}.registration
%define CIMV2_MOF %{_datadir}/%{name}/{HostedResourcePool,ElementCapabilities,HostedService,HostedDependency,RegisteredProfile,ComputerSystem,ElementConformsToProfile,HostedAccessPoint}.mof

# _If_ there is already a version of this installed, we must deregister
# the classes we plan to install in post, otherwise we may corrupt
# the pegasus repository.  This is convention in other provider packages

%{_datadir}/%{name}/provider-register.sh -d -t pegasus \
	-n root/virt \
	-r %{REGISTRATION} -m %{SCHEMA} >/dev/null 2>&1 || true
%{_datadir}/%{name}/provider-register.sh -d -t pegasus \
        -n root/interop \
        -r %{INTEROP_REG} -m %{INTEROP_MOF} >/dev/null 2>&1 || true
%{_datadir}/%{name}/provider-register.sh -d -t pegasus \
        -n root/PG_InterOp \
        -r %{PGINTEROP_REG} -m %{PGINTEROP_MOF} >/dev/null 2>&1 || true
%{_datadir}/%{name}/provider-register.sh -d -t pegasus \
        -n root/cimv2\
        -r %{CIMV2_REG} -m %{CIMV2_MOF} >/dev/null 2>&1 || true

%post
/sbin/ldconfig

%{_datadir}/%{name}/install_base_schema.sh %{_datadir}/%{name}

/etc/init.d/tog-pegasus condrestart

# Register MOFs
# NOTE: root/virt is registered twice, this is needed to actually
#       get a proper registration

%{_datadir}/%{name}/provider-register.sh -t pegasus \
	-n root/virt \
	-r %{REGISTRATION} -m %{SCHEMA} >/dev/null 2>&1 || true
%{_datadir}/%{name}/provider-register.sh -t pegasus \
	-n root/virt \
	-r %{REGISTRATION} -m %{SCHEMA} >/dev/null 2>&1 || true
%{_datadir}/%{name}/provider-register.sh -t pegasus \
        -n root/interop \
        -r %{INTEROP_REG} -m %{INTEROP_MOF} >/dev/null 2>&1 || true
%{_datadir}/%{name}/provider-register.sh -t pegasus \
        -n root/PG_InterOp \
        -r %{PGINTEROP_REG} -m %{PGINTEROP_MOF} >/dev/null 2>&1 || true
%{_datadir}/%{name}/provider-register.sh -t pegasus \
        -n root/cimv2\
        -r %{CIMV2_REG} -m %{CIMV2_MOF} >/dev/null 2>&1 || true

%preun

# Unregister MOFs

%{_datadir}/%{name}/provider-register.sh -d -t pegasus \
	-n root/virt \
	-r %{REGISTRATION} -m %{SCHEMA} >/dev/null 2>&1 || true
%{_datadir}/%{name}/provider-register.sh -d -t pegasus \
        -n root/interop \
        -r %{INTEROP_REG} -m %{INTEROP_MOF} >/dev/null 2>&1 || true
%{_datadir}/%{name}/provider-register.sh -d -t pegasus \
        -n root/PG_InterOp \
        -r %{PGINTEROP_REG} -m %{PGINTEROP_MOF} >/dev/null 2>&1 || true
%{_datadir}/%{name}/provider-register.sh -d -t pegasus \
        -n root/cimv2\
        -r %{CIMV2_REG} -m %{CIMV2_MOF} >/dev/null 2>&1 || true

%postun -p /sbin/ldconfig

%files
%defattr(-, root, root)
%{_sysconfdir}/libvirt/cim

%doc README COPYING doc/CodingStyle doc/SubmittingPatches
%doc base_schema/README.DMTF
%doc doc/*.html
%{_libdir}/lib*.so*
# CIM providers are .so modules, thus they belong in the main package
%{_libdir}/cmpi/lib*.so*
%{_datadir}/libvirt-cim
%{_datadir}/libvirt-cim/*.sh
%{_datadir}/libvirt-cim/*.mof
%{_datadir}/libvirt-cim/cimv*-interop_mof
%{_datadir}/libvirt-cim/cimv*-cimv2_mof
%{_datadir}/libvirt-cim/*.registration
%{_datadir}/libvirt-cim/cim_schema_*-MOFs.zip
%{_sysconfdir}/ld.so.conf.d/libvirt-cim.conf

%changelog
* Wed Jan 20 2010 Daniel Veillard <veillard@redhat.com> - 0.5.8-3.el5
- Change %pre to work around a schemas registration problem
- Resolves: rhbz#512233
* Tue Dec 15 2009 Daniel Veillard <veillard@redhat.com> - 0.5.8-2.el5
- Fix a regression in 0.5.8 with Xen networking
- Resolves: rhbz#512233
* Mon Dec  7 2009 Daniel Veillard <veillard@redhat.com> - 0.5.8-1.el5
- Update to 0.5.8 upstream
- update and cleanup spec file accordingly
- Resolves: rhbz#512233
* Thu Nov 26 2009 Daniel Veillard <veillard@redhat.com> - 0.5.7-3.el5
- makefile patch wasn't needed after all, reverting
- Resolves: rhbz#512233
* Thu Nov 26 2009 Daniel Veillard <veillard@redhat.com> - 0.5.7-2.el5
- add another makefile patch from upstream
- Resolves: rhbz#512233
* Wed Nov 25 2009 Daniel Veillard <veillard@redhat.com> - 0.5.7-1.el5
- Update to 0.5.7 upstream
- update spec file accordingly
- 4 patches for plugging leaks and a segfault
- add support for ACPI, PAE and APIC
- Resolves: rhbz#512233
* Mon Aug 17 2009 Daniel Veillard <veillard@redhat.com> - 0.5.5-3.el5
- drop abitrary rpm dependancies on xen, only libvirt is needed
- Resolves: rhbz#517579
* Wed Jun  3 2009 Daniel Veillard <veillard@redhat.com> - 0.5.5-2.el5
- Fix a regression in 0.5.x where Xen Fully Virt domain may not start
- Resolves: rhbz#503724
* Thu Apr 16 2009 Daniel Veillard <veillard@redhat.com> - 0.5.5-1.el5
- Rebase against new upstream release 0.5.5 fixing some leaks
- Resolves: rhbz#474681
- fix an unowned directory
- Resolves: rhbz#481810

* Mon Mar 30 2009 Daniel Veillard <veillard@redhat.com> - 0.5.4-2.el5
- we need to compile agaisnt a recent libvirt to enable features
- Related: rhbz#474681

* Mon Mar  9 2009 Daniel Veillard <veillard@redhat.com> - 0.5.4-1.el5
- rebase to new release 0.5.4
- Resolves: rhbz#474681

* Fri Nov  7 2008 Daniel Veillard <veillard@redhat.com> - 0.5.1-4.el5
- with an old libvirt we need to install diskpool.conf
- Resolves: rhbz#470276

* Tue Nov  4 2008 Daniel Veillard <veillard@redhat.com> - 0.5.1-3.el5
- couple of patches to add dynamic active vcpu reports
- Resolves: rhbz#469117

* Tue Oct  7 2008 Daniel Veillard <veillard@redhat.com> - 0.5.1-2.el5
- add missing tog-pegasus dependancy
- Resolves: rhbz#465916

* Tue Sep 23 2008 Daniel Veillard <veillard@redhat.com> - 0.5.1-1.el5
- Updated to 0.5.1 upstream release
- added a bunch of extra patches present upstream and in Fedora
- Resolves: rhbz#438555

* Fri Jul  4 2008 Daniel Veillard <veillard@redhat.com> - 0.5-1.el5
- Updated to 0.5 upstream release
- Resolves: rhbz#438555

* Fri Mar 14 2008 Dan Smith <danms@us.ibm.com> - 0.3-4
- Fixed loader config for 64-bit systems
- Added missing root/interop schema install
- Added RegisteredProfile.registration to install

* Fri Mar 07 2008 Dan Smith <danms@us.ibm.com> - 0.3-2
- Added KVM method enablement patch

* Mon Mar 03 2008 Dan Smith <danms@us.ibm.com> - 0.3-1
- Updated to latest upstream source

* Wed Feb 13 2008 Dan Smith <danms@us.ibm.com> - 0.2-1
- Updated to latest upstream source

* Thu Jan 17 2008 Dan Smith <danms@us.ibm.com> - 0.1-8
- Add ld.so.conf.d configuration

* Mon Jan 14 2008 Dan Smith <danms@us.ibm.com> - 0.1-7
- Update to offical upstream release
- Patch source to fix parallel make issue until fixed upstream

* Mon Jan 07 2008 Dan Smith <danms@us.ibm.com> - 0.1-3
- Remove RPATH on provider modules

* Mon Jan 07 2008 Dan Smith <danms@us.ibm.com> - 0.1-2
- Cleaned up Release
- Removed unnecessary Requires
- After install, condrestart pegasus
- Updated to latest source snapshot

* Fri Oct 26 2007 Daniel Veillard <veillard@redhat.com> - 0.1-1
- created
